@@ -1,26 +1,10 @@
-# -*- coding: utf-8 -*-
 # Copyright: (c) 2019, Jordan Borean (@jborean93) <jborean93@gmail.com>
 # MIT License (see LICENSE or https://opensource.org/licenses/MIT)
 
-import logging
-
-try:
-    from logging import NullHandler
-except ImportError:  # pragma: no cover
-
-    class NullHandler(logging.Handler):
-        def emit(self, record):
-            pass
-
-
-logger = logging.getLogger(__name__)
-logger.addHandler(NullHandler())
-
-
 MAX_PAYLOAD_SIZE = 65536
 
 
-class Dialects(object):
+class Dialects:
     """
     [MS-SMB2] v53.0 2017-09-15
 
