@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright: (c) 2019, Jordan Borean (@jborean93) <jborean93@gmail.com>
 # MIT License (see LICENSE or https://opensource.org/licenses/MIT)
 
@@ -25,7 +24,7 @@ from smbprotocol.structure import BytesField, EnumField, FlagField, IntField, St
 log = logging.getLogger(__name__)
 
 
-class SessionFlags(object):
+class SessionFlags:
     """
     [MS-SMB2] v53.0 2017-09-15
 
@@ -98,7 +97,7 @@ class SMB2SessionSetupRequest(Structure):
                 ),
             ]
         )
-        super(SMB2SessionSetupRequest, self).__init__()
+        super().__init__()
 
 
 class SMB2SessionSetupResponse(Structure):
@@ -151,7 +150,7 @@ class SMB2SessionSetupResponse(Structure):
                 ),
             ]
         )
-        super(SMB2SessionSetupResponse, self).__init__()
+        super().__init__()
 
 
 class SMB2Logoff(Structure):
@@ -167,10 +166,10 @@ class SMB2Logoff(Structure):
 
     def __init__(self):
         self.fields = OrderedDict([("structure_size", IntField(size=2, default=4)), ("reserved", IntField(size=2))])
-        super(SMB2Logoff, self).__init__()
+        super().__init__()
 
 
-class Session(object):
+class Session:
     def __init__(self, connection, username=None, password=None, require_encryption=True, auth_protocol="negotiate"):
         """
         [MS-SMB2] v53.0 2017-09-15
@@ -216,10 +215,9 @@ class Session(object):
             values are 'negotiate', 'ntlm' or 'kerberos'. Defaults to
             'negotiate'.
         """
-        log.info("Initialising session with username: %s" % username)
+        log.info("Initialising session with username: %s", username)
         self._connected = False
-        # This is only used by the client for pre-auth, the server will replace this value by one generated by itself.
-        self.session_id = random.randint(1, 2147483647) * -1
+        self.session_id = 0
         self.require_encryption = require_encryption
 
         # Table of tree connection, lookup by TreeConnect.tree_connect_id and
@@ -273,9 +271,7 @@ class Session(object):
                 protocol=self.auth_protocol,
             )
         except spnego.exceptions.SpnegoError as err:
-            raise SMBAuthenticationError("Failed to authenticate with server: %s" % str(err.message))
-
-        self.connection.preauth_session_table[self.session_id] = self
+            raise SMBAuthenticationError(f"Failed to authenticate with server: {err}") from err
 
         in_token = self.connection.gss_negotiate_token
         if self.auth_protocol != "negotiate":
@@ -285,7 +281,7 @@ class Session(object):
             try:
                 out_token = context.step(in_token)
             except spnego.exceptions.SpnegoError as err:
-                raise SMBAuthenticationError("Failed to authenticate with server: %s" % str(err.message))
+                raise SMBAuthenticationError(f"Failed to authenticate with server: {err}") from err
 
             if not out_token:
                 break
@@ -297,21 +293,21 @@ class Session(object):
 
             log.info("Sending SMB2_SESSION_SETUP request message")
             request = self.connection.send(session_setup, sid=self.session_id, credit_request=64)
+            request_id = request.message["message_id"].get_value()
 
             log.info("Receiving SMB2_SESSION_SETUP response message")
             try:
                 response = self.connection.receive(request)
             except MoreProcessingRequired as exc:
-                mid = request.message["message_id"].get_value()
                 response = exc.header
 
-            # If this is the first time we received the actual session_id, update the preauth table with the server
-            # assigned id.
-            session_id = response["session_id"].get_value()
-            if self.session_id < 0 and session_id:
-                del self.connection.preauth_session_table[self.session_id]
-                self.connection.preauth_session_table[session_id] = self
+            request_preauth = self.connection.preauth_integrity_session_hash_value.pop(request_id)
+            self.preauth_integrity_hash_value += request_preauth
 
+            # If this is the first time we received the actual session_id,
+            # record the returned id.
+            session_id = response["session_id"].get_value()
+            if self.session_id == 0 and session_id:
                 self.session_id = session_id
 
             setup_response = SMB2SessionSetupResponse()
@@ -322,14 +318,12 @@ class Session(object):
             status = response["status"].get_value()
             if status == NtStatus.STATUS_MORE_PROCESSING_REQUIRED:
                 log.info("More processing is required for SMB2_SESSION_SETUP")
-                preauth_value = self.connection.preauth_session_table.pop(response["message_id"].get_value())
-                self.preauth_integrity_hash_value.append(preauth_value)
 
-        log.info("Setting session id to %s" % self.session_id)
+        log.info("Setting session id to %s", self.session_id)
         self._connected = True
 
         # Move the session from the preauth table to the actual session table.
-        self.connection.session_table[self.session_id] = self.connection.preauth_session_table.pop(self.session_id)
+        self.connection.session_table[self.session_id] = self
 
         # session_key is the first 16 bytes, padded 0 if less than 16
         self.full_session_key = context.session_key
@@ -417,13 +411,13 @@ class Session(object):
             for tree in list(self.tree_connect_table.values()):
                 tree.disconnect()
 
-        log.info("Session: %s - Logging off of SMB Session" % self.username)
+        log.info("Session: %s - Logging off of SMB Session", self.username)
         logoff = SMB2Logoff()
-        log.info("Session: %s - Sending Logoff message" % self.username)
+        log.info("Session: %s - Sending Logoff message", self.username)
         log.debug(logoff)
         request = self.connection.send(logoff, sid=self.session_id)
 
-        log.info("Session: %s - Receiving Logoff response" % self.username)
+        log.info("Session: %s - Receiving Logoff response", self.username)
         res = self.connection.receive(request)
         res_logoff = SMB2Logoff()
         res_logoff.unpack(res["data"].get_value())
